<?php
/*                                                                                                                                                       
  mememe                                     ememem
    \ememememem                       ememememem/ 
     ememememememem               ememememememem  
      emememememememe           emememememememe   
         \memememememem       ememememememe/      
         emememememememe     emememememememe     
                 emememem   ememememe              
                     ememe ememe                   
                       emememe                     
                         eme
                          e  
                             
	^^ Title : Custom Maintenance Page			 
	^^ Create : 2021-05-10
	^^ For PS version 1.6
	   @author : EAGLEMEDIA.de <eagle@eaglemedia.de>
	   @copyright : EAGLEMEDIA.de	   
	   @license : See appended file licence.txt
	   @link : http://eaglemedia.de
*/ 

if (!defined('_PS_VERSION_'))
	exit;

if (file_exists(_PS_MODULE_DIR_.'maintenancepage/maintenancepage_help.php'))
    include_once(_PS_MODULE_DIR_.'maintenancepage/maintenancepage_help.php');

class maintenancepage extends Module
{ 
    
	private $_html = '';

	public function __construct()
	{
		$this->name = 'maintenancepage';
		$this->tab = 'front_office_features';
		$this->version = '1.6.0';
		$this->author = 'EAGLEMEDIA.de';
		$this->need_instance = 0;
		$this->secure_key = Tools::encrypt($this->name);
		
		$this->bootstrap = true;
		parent::__construct();

		$this->displayName = $this->l('Custom Maintenance Page');
		$this->description = $this->l('Adds an image animation with time control to your maintenance page incl. free text.');
		$this->ps_versions_compliancy = array('min' => '1.6.0.4', 'max' => '1.6.1.24');
	}

	public function install()
	{
		$this->_clearCache('*');        
        $this->changeFileMode();
        
		if( parent::install() &&			
			$this->registerHook('displayMaintenance') )
		{

			$res  = Configuration::updateValue('MAINTENANCEPAGE_TIME_SPAN', '00:00:01 - 07:00:00 - 13:00:00 - 20:00:00');
			$res &= Configuration::updateValue('MAINTENANCEPAGE_LOOP_TEMP', '');
			$res &= $this->createTables();

			if ($res)
				$this->installSamples();

			$this->disableDevice(Context::DEVICE_MOBILE);
			return (bool)$res;
		}
		return false;
	}
    
	private function changeFileMode()
	{      
		if ( file_exists(_PS_MODULE_DIR_.'maintenancepage/images') )          
            $ck_chmod_1 = chmod(_PS_MODULE_DIR_.'maintenancepage/images', 0777);
        if ( file_exists(_PS_MODULE_DIR_.'maintenancepage/test') )
            $ck_chmod_2 = chmod(_PS_MODULE_DIR_.'maintenancepage/test', 0777);
        if ( file_exists(_PS_MODULE_DIR_.'maintenancepage/test/index.php') )
            $ck_chmod_3 = chmod(_PS_MODULE_DIR_.'maintenancepage/test/index.php', 0777);
        if ( $ck_chmod_1 && $ck_chmod_2 && ck_chmod_3 )
            return true;
		return false;
	}

	private function installSamples()
	{
		$languages = Language::getLanguages(false);
		for ($i = 1; $i <= 4; ++$i)
		{
			$slide = new maintenancepageHelp();
			$slide->position = $i;
			$slide->active = 1;
			foreach ($languages as $language)
			{
				$slide->title[$language['id_lang']] = 'Sample '.$i;
				$slide->description[$language['id_lang']] = '
					<h2>WE\'LL BE BACK SOON</h2>
					<p>We are currently updating our shop and will be back really soon. Thanks for your patience.</p>
					<p><button class="btn btn-default" type="button">Link to us!</button></p>';
				$slide->legend[$language['id_lang']] = 'sample-'.$i;
				$slide->url[$language['id_lang']] = 'http://www.eaglemedia.de';
				$slide->image[$language['id_lang']] = 'sample-'.$i.'.png';
			}
			$slide->add();
		}
	}

	public function uninstall()
	{
		$this->_clearCache('*');
				
		if (parent::uninstall())
		{
			$res  = $this->deleteTables();
			$res &= Configuration::deleteByName('MAINTENANCEPAGE_TIME_SPAN');
			$res &= Configuration::deleteByName('MAINTENANCEPAGE_LOOP_TEMP');			
			return (bool)$res;
		}
		return false;
	}

	protected function createTables()
	{
		/* Slides */
		$res = (bool)Db::getInstance()->execute('
			  CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'maintenancepage` (
              `id_maintenancepage_slides` int(10) unsigned NOT NULL AUTO_INCREMENT,
              `id_shop` int(10) unsigned NOT NULL,
               PRIMARY KEY (`id_maintenancepage_slides`, `id_shop`)
             ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=UTF8;
		');

		/* Slides configuration */
		$res &= Db::getInstance()->execute('
			  CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'maintenancepage_slides` (
			  `id_maintenancepage_slides` int(10) unsigned NOT NULL AUTO_INCREMENT,
			  `position` int(10) unsigned NOT NULL DEFAULT \'0\',
			  `active` tinyint(1) unsigned NOT NULL DEFAULT \'0\',
			  PRIMARY KEY (`id_maintenancepage_slides`)
			) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=UTF8;
		');

		/* Slides lang configuration */
		$res &= Db::getInstance()->execute('
			  CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'maintenancepage_slides_lang` (
			  `id_maintenancepage_slides` int(10) unsigned NOT NULL,
			  `id_lang` int(10) unsigned NOT NULL,
			  `title` varchar(255) NOT NULL,
			  `description` text NOT NULL,
			  `legend` varchar(255) NOT NULL,
			  `url` varchar(255) NOT NULL,
			  `image` varchar(255) NOT NULL,
			  PRIMARY KEY (`id_maintenancepage_slides`,`id_lang`)
			) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=UTF8;
		');

		return $res;
	}

	protected function deleteTables()
	{
		$slides = $this->getSlides();
		foreach ($slides as $slide)
		{
			$to_del = new maintenancepageHelp($slide['id_slide']);
			$to_del->delete();
		}

		return Db::getInstance()->execute('
			DROP TABLE IF EXISTS `'._DB_PREFIX_.'maintenancepage`, `'._DB_PREFIX_.'maintenancepage_slides`, `'._DB_PREFIX_.'maintenancepage_slides_lang`;
		');
	}

	public function getContent()
	{
		$this->_html .= $this->headerHTML();

		if (Tools::isSubmit('submitAnimation') 
		 || Tools::isSubmit('delete_id_slide') 
		  || Tools::isSubmit('submitAnimations') 
		   || Tools::isSubmit('changeStatus') )
		{
			if ($this->postValidation())
			{
				$this->postProcess();
				$this->_html .= $this->renderForm();
				$this->_html .= $this->renderList();
			}
			else
				$this->_html .= $this->renderAddForm();

			$this->clearCache();
		}
		elseif (Tools::isSubmit('addSlide') || (Tools::isSubmit('id_slide') && $this->slideExists((int)Tools::getValue('id_slide'))))
			$this->_html .= $this->renderAddForm();
		else
		{
			$this->_html .= $this->renderForm();
			$this->_html .= $this->renderList();
		}

		return $this->_html;
	}

	private function postValidation()
	{
		$errors = array();

		if (Tools::isSubmit('submitAnimations'))
		{
		    $times = explode('-', str_replace(' ', '', Tools::getValue('MAINTENANCEPAGE_TIME_SPAN')));
			$count = 0;
			foreach ( $times as $time )
			{
			    $count++;
			    if ($count > 4)
				{
				    $errors[] = $this->l('Max 4 time stamps is allowed .');
					break;
				}
				
				if (strlen($time) != 8 || !preg_match('/[0-9:]{8}/', $time))
				    $errors[] = $this->l('Time stamps is invalid .');				
			}
						
			if (isset($times[1]) AND $times[0] > $times[1])
			    $errors[] = $this->l('Time stamp 2 is too low .');
			elseif (isset($times[2]) AND $times[1] > $times[2])
			    $errors[] = $this->l('Time stamp 3 is too low .');
			elseif (isset($times[3]) AND $times[2] > $times[3])
			    $errors[] = $this->l('Time stamp 4 is too low .');			
		} 
		elseif (Tools::isSubmit('changeStatus'))
		{
			if (!Validate::isInt(Tools::getValue('id_slide')))
				$errors[] = $this->l('Invalid slide');
		}
		elseif (Tools::isSubmit('submitAnimation'))
		{
			if (!Validate::isInt(Tools::getValue('active_slide')) || (Tools::getValue('active_slide') != 0 && Tools::getValue('active_slide') != 1))
				$errors[] = $this->l('Invalid slide state.');

			if (!Validate::isInt(Tools::getValue('position')) || (Tools::getValue('position') < 0))
				$errors[] = $this->l('Invalid slide position.');

			if (Tools::isSubmit('id_slide'))
			{
				//d(var_dump(Tools::getValue('id_slide')));
				if (!Validate::isInt(Tools::getValue('id_slide')) && !$this->slideExists(Tools::getValue('id_slide')))
					$errors[] = $this->l('Invalid id_slide');
			}

			$languages = Language::getLanguages(false);
			foreach ($languages as $language)
			{
				if (Tools::strlen(Tools::getValue('title_'.$language['id_lang'])) > 255)
					$errors[] = $this->l('The title is too long.');
				if (Tools::strlen(Tools::getValue('legend_'.$language['id_lang'])) > 255)
					$errors[] = $this->l('The caption is too long.');
				if (Tools::strlen(Tools::getValue('url_'.$language['id_lang'])) > 255)
					$errors[] = $this->l('The URL is too long.');
				if (Tools::strlen(Tools::getValue('description_'.$language['id_lang'])) > 4000)
					$errors[] = $this->l('The description is too long.');
				if (Tools::strlen(Tools::getValue('url_'.$language['id_lang'])) > 0 && !Validate::isUrl(Tools::getValue('url_'.$language['id_lang'])))
					$errors[] = $this->l('The URL format is not correct.');
				if (Tools::getValue('image_'.$language['id_lang']) != null && !Validate::isFileName(Tools::getValue('image_'.$language['id_lang'])))
					$errors[] = $this->l('Invalid filename.');
				if (Tools::getValue('image_old_'.$language['id_lang']) != null && !Validate::isFileName(Tools::getValue('image_old_'.$language['id_lang'])))
					$errors[] = $this->l('Invalid filename.');
			}

			$id_lang_default = (int)Configuration::get('PS_LANG_DEFAULT');
			if (Tools::strlen(Tools::getValue('title_'.$id_lang_default)) == 0)
				$errors[] = $this->l('The title is not set.');
			if (Tools::strlen(Tools::getValue('legend_'.$id_lang_default)) == 0)
				$errors[] = $this->l('The caption is not set.');
			if (Tools::strlen(Tools::getValue('url_'.$id_lang_default)) == 0)
				$errors[] = $this->l('The URL is not set.');
			if (!Tools::isSubmit('has_picture') && (!isset($_FILES['image_'.$id_lang_default]) || empty($_FILES['image_'.$id_lang_default]['tmp_name'])))
				$errors[] = $this->l('The image is not set.');
			if (Tools::getValue('image_old_'.$id_lang_default) && !Validate::isFileName(Tools::getValue('image_old_'.$id_lang_default)))
				$errors[] = $this->l('The image is not set.');
		} /* Validation for deletion */
		elseif (Tools::isSubmit('delete_id_slide') && (!Validate::isInt(Tools::getValue('delete_id_slide')) || !$this->slideExists((int)Tools::getValue('delete_id_slide'))))
			$errors[] = $this->l('Invalid id_slide');			


		if (count($errors))
		{
			$this->_html .= $this->displayError(implode('<br />', $errors));
			return false;
		}
		return true;
	}

	private function postProcess()
	{
		$errors = array();

		if (Tools::isSubmit('submitAnimations'))
		{
			$res = Configuration::updateValue('MAINTENANCEPAGE_TIME_SPAN', Tools::getValue('MAINTENANCEPAGE_TIME_SPAN'));

			$this->clearCache();
			if (!$res)
				$errors[] = $this->displayError($this->l('The configuration could not be updated.'));
			else
				Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true).'&conf=6&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name);
		} 
		elseif (Tools::isSubmit('changeStatus') && Tools::isSubmit('id_slide'))
		{
			$slide = new maintenancepageHelp((int)Tools::getValue('id_slide'));
			if ($slide->active == 0)
				$slide->active = 1;
			else
				$slide->active = 0;
			$res = $slide->update();
			$this->clearCache();
			$this->_html .= ($res ? $this->displayConfirmation($this->l('Configuration updated')) : $this->displayError($this->l('The configuration could not be updated.')));
		}
		elseif (Tools::isSubmit('submitAnimation'))
		{
			if (Tools::getValue('id_slide'))
			{
				$slide = new maintenancepageHelp((int)Tools::getValue('id_slide'));
				if (!Validate::isLoadedObject($slide))
				{
					$this->_html .= $this->displayError($this->l('Invalid id_slide'));
					return false;
				}
			}
			else
				$slide = new maintenancepageHelp();

			$slide->position = (int)Tools::getValue('position');

			$slide->active = (int)Tools::getValue('active_slide');


			$languages = Language::getLanguages(false);
			foreach ($languages as $language)
			{
				$slide->title[$language['id_lang']] = Tools::getValue('title_'.$language['id_lang']);
				$slide->url[$language['id_lang']] = Tools::getValue('url_'.$language['id_lang']);
				$slide->legend[$language['id_lang']] = Tools::getValue('legend_'.$language['id_lang']);
				$slide->description[$language['id_lang']] = Tools::getValue('description_'.$language['id_lang']);

				$type = Tools::strtolower(Tools::substr(strrchr($_FILES['image_'.$language['id_lang']]['name'], '.'), 1));
				$imagesize = @getimagesize($_FILES['image_'.$language['id_lang']]['tmp_name']);
				if (isset($_FILES['image_'.$language['id_lang']]) &&
					isset($_FILES['image_'.$language['id_lang']]['tmp_name']) &&
					!empty($_FILES['image_'.$language['id_lang']]['tmp_name']) &&
					!empty($imagesize) &&
					in_array(
						Tools::strtolower(Tools::substr(strrchr($imagesize['mime'], '/'), 1)), array(
							'jpg',
							  'gif',
							    'jpeg',
							      'png'
						)
					) &&
					in_array($type, array('jpg', 'gif', 'jpeg', 'png'))
				)
				{
					$temp_name = tempnam(_PS_TMP_IMG_DIR_, 'PS');
					$salt = 'sample-'; // sha1(microtime());

					if ($error = ImageManager::validateUpload($_FILES['image_'.$language['id_lang']]))
						$errors[] = $error;
					elseif (!$temp_name || !move_uploaded_file($_FILES['image_'.$language['id_lang']]['tmp_name'], $temp_name))
						return false;		
					elseif (!ImageManager::resize($temp_name, dirname(__FILE__).'/images/'.$salt.'-'.$_FILES['image_'.$language['id_lang']]['name'], null, null, $type))
						$errors[] = $this->displayError($this->l('An error occurred during the image upload process.'));
					if (isset($temp_name))
						@unlink($temp_name);
					$slide->image[$language['id_lang']] = $salt.'-'.$_FILES['image_'.$language['id_lang']]['name'];
				}
				elseif (Tools::getValue('image_old_'.$language['id_lang']) != '')
					$slide->image[$language['id_lang']] = Tools::getValue('image_old_'.$language['id_lang']);
			}

			if (!$errors)
			{
				if (!Tools::getValue('id_slide'))
				{
					if (!$slide->add())
						$errors[] = $this->displayError($this->l('The slide could not be added.'));
				}
				elseif (!$slide->update())
					$errors[] = $this->displayError($this->l('The slide could not be updated.'));
				$this->clearCache();
			}
		}
		elseif (Tools::isSubmit('delete_id_slide'))
		{
			$slide = new maintenancepageHelp((int)Tools::getValue('delete_id_slide'));
			$res = $slide->delete();
			$this->clearCache();
			if (!$res)
				$this->_html .= $this->displayError('Could not delete.');
			else
				Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true).'&conf=1&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name);
		}

		if (count($errors))
			$this->_html .= $this->displayError(implode('<br />', $errors));
		elseif (Tools::isSubmit('submitAnimation') && Tools::getValue('id_slide'))
			Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true).'&conf=4&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name);
		elseif (Tools::isSubmit('submitAnimation'))
			Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true).'&conf=3&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name);
	}

	private function prepareHook()
	{
		$timeNow = date('H:i:s');		
		$times = explode('-', str_replace(' ', '', Configuration::get('MAINTENANCEPAGE_TIME_SPAN')));		
		$count = 0;
		foreach ($times as $time)
		{	
			$count++;		
			if ($count <= 4 && $time > $timeNow)
			{
				$loop = $count - 1;
				break;
			}
			else if ($count == 4 && $time < $timeNow)
			{
				$loop = $count;				
			}						  
		}        
		
		if (Configuration::get('MAINTENANCEPAGE_LOOP_TEMP') != $loop)
		{		    
		    $this->clearCache();
			Configuration::updateValue('MAINTENANCEPAGE_LOOP_TEMP', (int)$loop);
		}
			
		if (!$this->isCached('maintenancepage.tpl', $this->getCacheId()))
		{
			$slides = $this->getSlides(true);

			if (is_array($slides))
				foreach ($slides as &$slide)
				{
					$slide['sizes'] = @getimagesize((dirname(__FILE__).DIRECTORY_SEPARATOR.'images'.DIRECTORY_SEPARATOR.$slide['image']));
					if (isset($slide['sizes'][3]) && $slide['sizes'][3])
						$slide['size'] = $slide['sizes'][3];
				}

			if (!$slides)
				return false;

			Context::getContext()->smarty->assign(          
				array(
			    'maintenancepage_slides' => $slides,
				'eligible_loop' => $loop
			    )
			);
		}
		return true;
	}    

	public function hookDisplayMaintenance($params)
	{  
		if ($this->prepareHook() !== true)
			return false;
	
		return $this->display(__FILE__, 'maintenancepage.tpl', $this->getCacheId());
	}

	public function clearCache()
	{
		$this->_clearCache('maintenancepage.tpl');
	}
	
	/* For install and uninstall process */
	public function _clearCache($template, $cache_id = NULL, $compile_id = NULL)
	{
		parent::_clearCache('maintenancepage.tpl');
	}    

	public function headerHTML()
	{
		if (Tools::getValue('controller') != 'AdminModules' && Tools::getValue('configure') != $this->name)
			return;		

		$this->context->controller->addJqueryUI('ui.sortable');
		/* Style & js for fieldset 'slides configuration'*/
		$html = '
		<script>
			$(function() {
				var $mySlides = $("#slides");
				$mySlides.sortable({
					opacity: 0.6,
					cursor: "move",
					update: function() {
						var order = $(this).sortable("serialize") + "&action=updateSlidesPosition";
						$.post("'.$this->context->shop->physical_uri.$this->context->shop->virtual_uri.'modules/'.$this->name.'/'.$this->name.'_ajax.php?secure_key='.$this->secure_key.'", order);
						}
					});
				$mySlides.hover(function() {
					$(this).css("cursor","move");
					},
					function() {
					$(this).css("cursor","auto");
				});
			});
            
            $(document).ready(function(){
                $(".maintenancepage pre").css("display", "none");
                $(".maintenancepage.panel").hover(
                function(){
                    $(".maintenancepage pre").stop().slideDown("slow");
                },
                function(){
                    $(".maintenancepage pre").stop().slideUp("slow");
                });
            });
		</script>
		';

		return $html;
	}
    #/*
	public function getNextPosition()
	{
		$row = Db::getInstance(_PS_USE_SQL_SLAVE_)->getRow('
			SELECT MAX(hss.`position`) AS `next_position`
			FROM `'._DB_PREFIX_.'maintenancepage_slides` hss, `'._DB_PREFIX_.'maintenancepage` hs
			WHERE hss.`id_maintenancepage_slides` = hs.`id_maintenancepage_slides` AND hs.`id_shop` = '.(int)$this->context->shop->id
		);

		return (++$row['next_position']);
	}
   # */
	public function getSlides($active = null)
	{
		$this->context = Context::getContext();		
		$id_lang = $this->context->language->id;

		return Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
			SELECT hs.`id_maintenancepage_slides` as id_slide, hssl.`image`, hss.`position`, hss.`active`, hssl.`title`,
			hssl.`url`, hssl.`legend`, hssl.`description`, hssl.`image`
			FROM '._DB_PREFIX_.'maintenancepage hs
			LEFT JOIN '._DB_PREFIX_.'maintenancepage_slides hss ON (hs.id_maintenancepage_slides = hss.id_maintenancepage_slides)
			LEFT JOIN '._DB_PREFIX_.'maintenancepage_slides_lang hssl ON (hss.id_maintenancepage_slides = hssl.id_maintenancepage_slides)
			WHERE hssl.`id_lang` = '.(int)$id_lang.
			($active ? ' AND hss.`active` = 1' : ' ').'
			ORDER BY hss.position'
		);
	}
    #/*
	public function getAllImagesBySlidesId($id_slides, $active = null, $id_shop = null)
	{
		$this->context = Context::getContext();
		$images = array();

		if (!isset($id_shop))
			$id_shop = $this->context->shop->id;

		$results = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
			SELECT hssl.`image`, hssl.`id_lang`
			FROM '._DB_PREFIX_.'maintenancepage hs
			LEFT JOIN '._DB_PREFIX_.'maintenancepage_slides hss ON (hs.id_maintenancepage_slides = hss.id_maintenancepage_slides)
			LEFT JOIN '._DB_PREFIX_.'maintenancepage_slides_lang hssl ON (hss.id_maintenancepage_slides = hssl.id_maintenancepage_slides)
			WHERE hs.`id_maintenancepage_slides` = '.(int)$id_slides.' AND hs.`id_shop` = '.(int)$id_shop.
			($active ? ' AND hss.`active` = 1' : ' ')
		);

		foreach ($results as $result)
			$images[$result['id_lang']] = $result['image'];

		return $images;
	}
   #*/
	public function displayStatus($id_slide, $active)
	{
		$title = ((int)$active == 0 ? $this->l('Disabled') : $this->l('Enabled'));
		$icon = ((int)$active == 0 ? 'icon-remove' : 'icon-check');
		$class = ((int)$active == 0 ? 'btn-danger' : 'btn-success');
		$html = '<a class="btn '.$class.'" href="'.AdminController::$currentIndex.
			'&configure='.$this->name.'
				&token='.Tools::getAdminTokenLite('AdminModules').'
				&changeStatus&id_slide='.(int)$id_slide.'" title="'.$title.'"><i class="'.$icon.'"></i> '.$title.'</a>';

		return $html;
	}

	public function slideExists($id_slide)
	{
		$req = 'SELECT hs.`id_maintenancepage_slides` as id_slide
				FROM `'._DB_PREFIX_.'maintenancepage` hs
				WHERE hs.`id_maintenancepage_slides` = '.(int)$id_slide;
		$row = Db::getInstance(_PS_USE_SQL_SLAVE_)->getRow($req);

		return ($row);
	}

	public function renderList()
	{
		$slides = $this->getSlides();
		foreach ($slides as $key => $slide)
			$slides[$key]['status'] = $this->displayStatus($slide['id_slide'], $slide['active']);

		$this->context->smarty->assign(
			array(
				'link' => $this->context->link,
				'slides' => $slides,
				'image_baseurl' => $this->_path.'images/'
			)
		);

		return $this->display(__FILE__, 'list.tpl');
	}

	public function renderAddForm()
	{
	    $fields_form_1 = '
        <div class="maintenancepage text-center hidden">
            '.$this->l('Have a look at my modules for PrestaShop').' -
            <a href="https://eaglemedia.de/cms.php?s=prestashop-module" target="_blank"><b>MODULE</b></a>
            <p class="clear"> </p>
            '.$this->l('Made with').' <i class="icon-heart"></i> '.$this->l('by').'
            <a href="http://eaglemedia.de" target="_blank"><b>EAGLEMEDIA</b></a>
            <p class="clear"><br/> </p>

            <form action="https://www.paypal.com/donate" method="post" target="_blank">
                <input type="hidden" name="hosted_button_id" value="ALLRFT5RZJVHN" />
                <input type="image" src="https://www.paypalobjects.com/de_DE/DE/i/btn/btn_donateCC_LG.gif" 
                       border="0" name="submit" title="PayPal - The safer, easier way to pay online!" alt="Donate with PayPal button" />

                <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
            </form>
            <p class="clear"><br/><br/> </p>	
        </div>';         
        
		$fields_form_2 = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Slide informations'),
					'icon' => 'icon-cogs'
				),
				'input' => array(
					array(
						'type' => 'hidden',					
						'name' => 'id_slide',						
					),
					array(
						'type' => 'file_lang',
						'label' => $this->l('Select a file'),
						'name' => 'image',
						'lang' => true,
						'desc' => $this->l(sprintf('Max image size %s', ini_get('upload_max_filesize')))
					),
					array(
						'type' => 'text',
						'label' => $this->l('Title'),
						'name' => 'title',
						'lang' => true,
					),
					array(
						'type' => 'text',
						'label' => $this->l('URL'),
						'name' => 'url',
						'lang' => true,
					),
					array(
						'type' => 'text',
						'label' => $this->l('Caption'),
						'name' => 'legend',
						'lang' => true,
					),
					array(
						'type' => 'textarea',
						'label' => $this->l('Description'),
						'name' => 'description',
						'autoload_rte' => true,
						'lang' => true,
					),
					array(
						'type' => 'switch',
						'label' => $this->l('Active'),
						'name' => 'active_slide',
						'is_bool' => true,
						'values' => array(
							array(
								'id' => 'active_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'active_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
				),
				'submit' => array(
					'title' => $this->l('Save'),
				)
			),
		);
        
		$fields_form_3 = '
        <div class="maintenancepage text-center">
            '.$this->l('See').' -
            <a href="'.Context::getContext()->shop->getBaseURL(true).'modules/maintenancepage/_install_guide.txt" target="_blank"><b>Installation Guide</b></a>
            <p class="clear"><br/><br/> </p>	
        </div>
        ';

		if (Tools::isSubmit('id_slide') && $this->slideExists((int)Tools::getValue('id_slide')))
		{
			$slide = new maintenancepageHelp((int)Tools::getValue('id_slide'));
			$fields_form['form']['input'][] = array('type' => 'hidden', 'name' => 'id_slide');
			$fields_form['form']['images'] = $slide->image;

			$has_picture = true;

			foreach (Language::getLanguages(false) as $lang)
				if (!isset($slide->image[$lang['id_lang']]))
					$has_picture &= false;

			if ($has_picture)
				$fields_form['form']['input'][] = array('type' => 'hidden', 'name' => 'has_picture');
		}

		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table = $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$this->fields_form = array();
		$helper->module = $this;
		$helper->identifier = $this->identifier;
		$helper->submit_action = 'submitAnimation';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$language = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->tpl_vars = array(
			'base_url' => $this->context->shop->getBaseURL(),
			'language' => array(
				'id_lang' => $language->id,
				'iso_code' => $language->iso_code
			),
			'fields_value' => $this->getAddFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id,
			'image_baseurl' => $this->_path.'images/'
		);

		$helper->override_folder = '/';

		return $fields_form_1.$helper->generateForm(array($fields_form_2)).$fields_form_3;
	}

	public function renderForm()
	{        
	    $fields_form_1 = '
        <div class="maintenancepage text-center hidden">
            '.$this->l('Have a look at my modules for PrestaShop').' -
            <a href="https://eaglemedia.de/cms.php?s=prestashop-module" target="_blank"><b>MODULE</b></a>
            <p class="clear"> </p>
            '.$this->l('Made with').' <i class="icon-heart"></i> '.$this->l('by').'
            <a href="http://eaglemedia.de" target="_blank"><b>EAGLEMEDIA</b></a>
            <p class="clear"><br/> </p>

            <form action="https://www.paypal.com/donate" method="post" target="_blank">
                <input type="hidden" name="hosted_button_id" value="ALLRFT5RZJVHN" />
                <input type="image" src="https://www.paypalobjects.com/de_DE/DE/i/btn/btn_donateCC_LG.gif" 
                       border="0" name="submit" title="PayPal - The safer, easier way to pay online!" alt="Donate with PayPal button" />

                <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
            </form>
            <p class="clear"><br/><br/> </p>	
        </div>'; 
        
        $fields_form_2 = '
        <div class="maintenancepage panel">
            <div class="panel-heading">
				<i class="icon-code"></i> '.$this->l('Html').'</div>
            <pre>'.htmlentities($this->overviewMaintenancePage()).'</pre>            
         </div>
        <div class="maintenancepage text-center">
            '.$this->l('Overview').' -
            <a href="'.Context::getContext()->shop->getBaseURL(true).'modules/maintenancepage/test/" target="_blank"><b>'.$this->l('Maintenance Page').'</b></a>
            <p class="clear"><br/><br/> </p>	
        </div>
        '; 
        
		$fields_form_3 = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs'
				),
				'input' => array(
					array(
						'type' => 'text',
						'label' => $this->l('Time span'),
						'name' => 'MAINTENANCEPAGE_TIME_SPAN',
						'desc' => $this->l('Time span to display from slider 1/2/3/4. Write time control in this form( hh.mm.ss ) 00:00:00 - 00:00:00 or 00:00:00 - 00:00:00 - 00:00:00 etc. in addition of image amount . Actual server time : ').date('H:i:s')
					)
				),
				'submit' => array(
					'title' => $this->l('Save'),
				)
			),
		);
        
		$fields_form_4 = '
        <div class="maintenancepage text-center">
            '.$this->l('See').' -
            <a href="'.Context::getContext()->shop->getBaseURL(true).'modules/maintenancepage/_install_guide.txt" target="_blank"><b>'.$this->l('Installation Guide').'</b></a>
            <p class="clear"><br/><br/> </p>	
        </div>
        ';      

		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table = $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$this->fields_form = array();

		$helper->identifier = $this->identifier;
		$helper->submit_action = 'submitAnimations';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id
		);

		return $fields_form_1.$fields_form_2.$helper->generateForm(array($fields_form_3)).$fields_form_4;
	}

	public function getConfigFieldsValues()
	{
		return array(
			'MAINTENANCEPAGE_TIME_SPAN' => Tools::getValue('MAINTENANCEPAGE_TIME_SPAN', Configuration::get('MAINTENANCEPAGE_TIME_SPAN'))
		);
	}

	public function getAddFieldsValues()
	{
		$fields = array();

		if (Tools::isSubmit('id_slide') && $this->slideExists((int)Tools::getValue('id_slide')))
		{
			$slide = new maintenancepageHelp((int)Tools::getValue('id_slide'));
			$fields['id_slide'] = (int)Tools::getValue('id_slide', $slide->id);
		}
		else
			$slide = new maintenancepageHelp();

		$fields['active_slide'] = Tools::getValue('active_slide', $slide->active);
		$fields['has_picture'] = true;

		$languages = Language::getLanguages(false);

		foreach ($languages as $lang)
		{
			$fields['image'][$lang['id_lang']] = Tools::getValue('image_'.(int)$lang['id_lang']);
			$fields['title'][$lang['id_lang']] = Tools::getValue('title_'.(int)$lang['id_lang'], $slide->title[$lang['id_lang']]);
			$fields['url'][$lang['id_lang']] = Tools::getValue('url_'.(int)$lang['id_lang'], $slide->url[$lang['id_lang']]);
			$fields['legend'][$lang['id_lang']] = Tools::getValue('legend_'.(int)$lang['id_lang'], $slide->legend[$lang['id_lang']]);
			$fields['description'][$lang['id_lang']] = Tools::getValue('description_'.(int)$lang['id_lang'], $slide->description[$lang['id_lang']]);
		}

		return $fields;
	}    

    private function overviewMaintenancePage()
    {    
        $tpl = $this->context->smarty->createTemplate(_PS_THEME_DIR_.'maintenance.tpl');               
        $tpl->assign($this->initLogoAndFavicon());
        $tpl->assign(
            array(
                'HOOK_MAINTENANCE' => Hook::exec('displayMaintenance', array()),
                'css_dir' => _THEME_CSS_DIR_,
                'nobots' => true
            )
        );
        $tpl = $tpl->fetch();  
        
        if ( $this->testMaintenancePage($tpl) )           
            return $tpl;       
    }
    
    private function testMaintenancePage($tpl)
    {     
		if ( file_exists(_PS_MODULE_DIR_.'maintenancepage/test/index.php') ) 
        { 	
            $head = '
<?php
/*                                                                                                                                                       
  mememe                                     ememem
    \ememememem                       ememememem/ 
     ememememememem               ememememememem  
      emememememememe           emememememememe   
         \memememememem       ememememememe/      
         emememememememe     emememememememe     
                 emememem   ememememe              
                     ememe ememe                   
                       emememe                     
                         eme
                          e  
                             
	^^ Title : Custom Maintenance Page			 
	^^ Create : 2021-05-10
	^^ For PS version 1.6
	   @author : EAGLEMEDIA.de <eagle@eaglemedia.de>
	   @copyright : EAGLEMEDIA.de	   
	   @license : See appended file licence.txt
	   @link : http://eaglemedia.de
*/
?>
            ';
            
            $content = $head . $tpl;
			if ( $handle = fopen(_PS_MODULE_DIR_.'maintenancepage/test/index.php', 'w') ) 
			{ 
				$status = fputs( $handle, $content );			
				fclose( $handle ); 
			}
            
            if ( $status !== false )
                return true;
        }
        return false;
    }
    
    private function initLogoAndFavicon()
    {
        $mobile_device = $this->context->getMobileDevice();

        if ($mobile_device && Configuration::get('PS_LOGO_MOBILE')) {
            $logo = $this->context->link->getMediaLink(_PS_IMG_.Configuration::get('PS_LOGO_MOBILE').'?'.Configuration::get('PS_IMG_UPDATE_TIME'));
        } else {
            $logo = $this->context->link->getMediaLink(_PS_IMG_.Configuration::get('PS_LOGO'));
        }

        return array(
            'favicon_url'       => _PS_IMG_.Configuration::get('PS_FAVICON'),
            'logo_image_width'  => ($mobile_device == false ? Configuration::get('SHOP_LOGO_WIDTH')  : Configuration::get('SHOP_LOGO_MOBILE_WIDTH')),
            'logo_image_height' => ($mobile_device == false ? Configuration::get('SHOP_LOGO_HEIGHT') : Configuration::get('SHOP_LOGO_MOBILE_HEIGHT')),
            'logo_url'          => $logo
        );
    }
    
}
